pub struct WhichKeyBackspace;Trait Implementations
Sourceimpl Clone for WhichKeyBackspace
impl Clone for WhichKeyBackspace
Sourcefn clone(&self) -> WhichKeyBackspace
fn clone(&self) -> WhichKeyBackspace
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandTrait for WhichKeyBackspace
impl CommandTrait for WhichKeyBackspace
Sourcefn name(&self) -> &'static str
fn name(&self) -> &'static str
Unique identifier for this command (e.g.,
cursor_up, enter_insert_mode)Sourcefn description(&self) -> &'static str
fn description(&self) -> &'static str
Human-readable description for help/documentation
Sourcefn execute(&self, _ctx: &mut ExecutionContext<'_>) -> CommandResult
fn execute(&self, _ctx: &mut ExecutionContext<'_>) -> CommandResult
Execute the command on the given buffer Read more
Sourcefn valid_modes(&self) -> Option<Vec<ModeState>>
fn valid_modes(&self) -> Option<Vec<ModeState>>
Optional: which modes this command is valid in (None = all modes)
Sourcefn supports_count(&self) -> bool
fn supports_count(&self) -> bool
Optional: does this command support repeat count?
Sourcefn is_jump(&self) -> bool
fn is_jump(&self) -> bool
Whether this command is a “jump” that should be recorded in the jump list Read more
Sourcefn is_text_modifying(&self) -> bool
fn is_text_modifying(&self) -> bool
Whether this command modifies buffer text content Read more
Sourceimpl Debug for WhichKeyBackspace
impl Debug for WhichKeyBackspace
Sourceimpl Default for WhichKeyBackspace
impl Default for WhichKeyBackspace
Sourcefn default() -> WhichKeyBackspace
fn default() -> WhichKeyBackspace
Returns the “default value” for a type. Read more
Sourceimpl Event for WhichKeyBackspace
impl Event for WhichKeyBackspace
impl Copy for WhichKeyBackspace